@@ -1,5 +1,5 @@
 from bs4 import BeautifulSoup
-from chibi.atlas import Chibi_atlas_ignore_case, _wrap, loads
+from chibi.atlas import Chibi_atlas_ignore_case, _wrap, loads, Atlas
 from marshmallow import Schema
 
 
@@ -110,10 +110,18 @@ class Response:
         serializer = self.get_serializer()
         if serializer:
             many = self.native_is_many
-            parse = serializer().load( parse, many=many )
+            serializer = serializer()
+            serializer.context[ 'url' ] = self.url
+            parse = serializer.load( parse, many=many )
+            if isinstance( parse, ( dict, list ) ):
+                parse = Atlas( parse )
         return parse
 
     @property
     def native_is_many( self ):
         parse = self.parse_content_type()
         return isinstance( parse, list )
+
+    @property
+    def ok( self ):
+        return self.status_code == 200
